==> kogito-test-utils-1.7.0.Final-sources.jar: org/kie/kogito/testcontainers/quarkus/MongoDBQuarkusTestResource.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.testcontainers.quarkus;

import org.kie.kogito.resources.ConditionalQuarkusTestResource;
import org.kie.kogito.testcontainers.KogitoMongoDBContainer;

/**
 * MongoDB quarkus resource that works within the test lifecycle.
 *
 */
public class MongoDBQuarkusTestResource extends ConditionalQuarkusTestResource<KogitoMongoDBContainer> {

    public static final String MONGODB_CONNECTION_PROPERTY = "quarkus.mongodb.connection-string";

    public MongoDBQuarkusTestResource() {
        super(new KogitoMongoDBContainer());
    }

    @Override
    protected String getKogitoProperty() {
        return MONGODB_CONNECTION_PROPERTY;
    }

    @Override
    protected String getKogitoPropertyValue() {
        return getTestResource().getReplicaSetUrl();
    }

    public static class Conditional extends MongoDBQuarkusTestResource {

        public Conditional() {
            super();
            enableConditional();
        }
    }
}

==> kogito-test-utils-1.10.0.Final-sources.jar: org/kie/kogito/testcontainers/quarkus/MongoDBQuarkusTestResource.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.testcontainers.quarkus;

import java.util.Map;

import org.kie.kogito.resources.ConditionalQuarkusTestResource;
import org.kie.kogito.testcontainers.KogitoMongoDBContainer;

import static java.util.Collections.singletonMap;

/**
 * MongoDB quarkus resource that works within the test lifecycle.
 *
 */
public class MongoDBQuarkusTestResource extends ConditionalQuarkusTestResource<KogitoMongoDBContainer> {

    public static final String MONGODB_CONNECTION_PROPERTY = "quarkus.mongodb.connection-string";

    public MongoDBQuarkusTestResource() {
        super(new KogitoMongoDBContainer());
    }

    @Override
    protected Map<String, String> getProperties() {
        return singletonMap(MONGODB_CONNECTION_PROPERTY, getTestResource().getReplicaSetUrl());
    }

    public static class Conditional extends MongoDBQuarkusTestResource {

        public Conditional() {
            super();
            enableConditional();
        }
    }
}
